@@ -1,5 +1,5 @@
 `displayCI` <-
-function (ci, digit = 2) 
+function (ci, digit = 2, unit = "") 
 {
     d <- 1
     if (is.matrix(ci) == TRUE) {
@@ -10,8 +10,8 @@ function (ci, digit = 2)
     }
     disp.ci <- rep(NA, d)
     for (i in 1:d) {
-        disp.ci[i] <- paste("[", disp(ci[i, 1], digit), ", ", 
-            disp(ci[i, 2], digit), "]", sep = "")
+        disp.ci[i] <- paste("[", disp(ci[i, 1], digit), unit, 
+            ", ", disp(ci[i, 2], digit), unit, "]", sep = "")
     }
     return(disp.ci)
 }
