@@ -1,12 +1,12 @@
 `tableContinuous` <-
-function (vars, nams, group = NA, subset = NA, disp.cols = c("n", 
+function (vars, nams, group = NA, subset = NA, stats = c("n", 
     "min", "q1", "median", "mean", "q3", "max", "s", "iqr", "na"), 
     prec = 1, col.tit = NA, print.pval = c("none", "anova", "kruskal")[1], 
-    cap = "", lab = "") 
+    declare.zero = 10^-10, cap = "", lab = "", disp.cols = NA) 
 {
-    dc <- c("n", "min", "q1", "median", "mean", "q3", "max", 
-        "s", "iqr", "na")
-    disp.cols.num <- pmatch(disp.cols, dc)
+    if (identical(disp.cols, NA) == FALSE) {
+        stats <- disp.cols
+    }
     for (i in 1:length(nams)) {
         nams[i] <- gsub("_", "\\\\_", as.character(nams[i]))
     }
@@ -17,26 +17,27 @@ function (vars, nams, group = NA, subset = NA, disp.cols = c("n",
         }
     }
     if (max(is.na(col.tit) == TRUE) == 1) {
-        col.tit <- c("{\\bf Variable}", "{\\bf Levels}", "n", 
+        col.tit <- c("{\\bf Variable}", "{\\bf Levels}", "$n$", 
             "Min", "$q_1$", "$\\widetilde{x}$", "$\\bar{x}$", 
             "$q_3$", "Max", "$s$", "IQR", "\\#NA")
     }
+    group <- factor(group, exclude = NULL)
     n.levels <- 1
     if (max(is.na(group) == 1) == 0) {
         group <- as.factor(group)
         n.levels <- length(levels(group))
     }
+    ncols <- length(stats)
+    s1 <- unlist(lapply(stats, is.character))
+    s1 <- (1:ncols)[s1]
+    s2 <- unlist(lapply(stats, is.function))
+    s2 <- (1:ncols)[s2]
     n.var <- length(nams)
     out <- matrix(NA, ncol = 12, nrow = (n.levels + 1) * n.var)
     out <- data.frame(out)
-    if (n.levels == 1) {
-        prec <- c(rep(0, 3), rep(prec, 8), 0)
-        ali <- "ll"
-    }
-    if (n.levels > 1) {
-        prec <- c(rep(0, 3), rep(prec, 9), 0)
-        ali <- "lll"
-    }
+    out.fct <- matrix(NA, ncol = length(s2), nrow = (n.levels + 
+        1) * n.var)
+    out.fct <- data.frame(out.fct)
     for (i in 1:n.var) {
         ind <- (i - 1) * (n.levels + 1) + 1:(n.levels + 1)
         splits <- list(vars[[i]])
@@ -44,7 +45,7 @@ function (vars, nams, group = NA, subset = NA, disp.cols = c("n",
             splits <- split(vars[[i]], group)
         }
         for (j in 1:n.levels) {
-            tmp <- splits[[j]]
+            tmp <- as.vector(splits[[j]])
             if (sum(is.na(tmp) == FALSE) != 0) {
                 out[ind[j], 3] <- sum(is.na(tmp) == FALSE)
                 out[ind[j], 4:9] <- summary(tmp)[1:6]
@@ -52,18 +53,37 @@ function (vars, nams, group = NA, subset = NA, disp.cols = c("n",
                 out[ind[j], 11] <- out[ind[j], 8] - out[ind[j], 
                   5]
                 out[ind[j], 12] <- sum(is.na(tmp) == TRUE)
+                if (length(s2) > 0) {
+                  for (f in 1:length(s2)) {
+                    out.fct[ind[j], f] <- stats[[s2[f]]](tmp[is.na(tmp) == 
+                      FALSE])
+                  }
+                }
             }
         }
-        out[max(ind), 3] <- sum(is.na(vars[[i]]) == FALSE)
-        out[max(ind), 4:9] <- summary(vars[[i]])[1:6]
-        out[max(ind), 10] <- sd(vars[[i]], na.rm = TRUE)
+        vi <- as.vector(vars[[i]])
+        out[max(ind), 3] <- sum(is.na(vi) == FALSE)
+        out[max(ind), 4:9] <- summary(vi)[1:6]
+        out[max(ind), 10] <- sd(vi, na.rm = TRUE)
         out[max(ind), 11] <- out[max(ind), 8] - out[max(ind), 
             5]
-        out[max(ind), 12] <- sum(is.na(vars[[i]]) == TRUE)
+        out[max(ind), 12] <- sum(is.na(vi) == TRUE)
+        out[, 3:12][abs(out[, 3:12]) <= declare.zero] <- 0
+        if (length(s2) > 0) {
+            for (f in 1:length(s2)) {
+                out.fct[max(ind), f] <- stats[[s2[f]]](vi[is.na(vi) == 
+                  FALSE])
+            }
+            out.fct[abs(out.fct) <= declare.zero] <- 0
+        }
         ind1 <- n.levels > 1
         ind2 <- print.pval %in% c("anova", "kruskal")
-        ind3 <- min(unlist(lapply(splits, sum, na.rm = TRUE))) > 
-            0
+        ind3 <- 1
+        for (s in 1:length(splits)) {
+            if (sum(is.na(splits[[1]]) == TRUE) == length(splits[[1]])) {
+                ind3 <- 0
+            }
+        }
         if (ind1 * ind2 * ind3 == 1) {
             if (print.pval == "anova") {
                 pval <- anova(lm(vars[[i]] ~ group))$"Pr(>F)"[1]
@@ -75,36 +95,59 @@ function (vars, nams, group = NA, subset = NA, disp.cols = c("n",
                 format.pval(pval), sep = "")
         }
     }
-    align.disp.cols <- ""
-    disp.cols2 <- c(1:2, 2 + disp.cols.num)
-    for (i in 1:length(disp.cols.num)) {
-        align.disp.cols <- paste(align.disp.cols, "r", sep = "")
-    }
-    out2 <- out[, disp.cols2]
+    dc <- c("n", "min", "q1", "median", "mean", "q3", "max", 
+        "s", "iqr", "na")
+    stats.num <- pmatch(stats[s1], dc)
+    align.stats <- ""
+    stats2 <- c(2 + stats.num)
+    out2 <- matrix(NA, ncol = 2 + length(s1) + length(s2), nrow = (n.levels + 
+        1) * n.var)
+    out2 <- data.frame(out2)
+    out2[, c(1, 2, 2 + s1)] <- out[, c(1, 2, stats2)]
+    out2[, 2 + s2] <- out.fct
     out2[((1:n.var) - 1) * (n.levels + 1) + 1, 1] <- nams
-    dimnames(out2)[[2]] <- col.tit[disp.cols2]
-    tmp <- cumsum(rep(n.levels, n.var) + 1)
-    hlines <- sort(c(0, tmp - 1, rep(tmp, 2)))
-    if (n.levels > 1) {
-        out2[, 2] <- rep(c(levels(group), "all"), times = n.var)
-        xtab1 <- xtable(out2, digits = prec[c(1, 1 + disp.cols2)], 
-            align = paste(ali, align.disp.cols, sep = ""), caption = cap, 
-            label = lab)
-        xtab2 <- print(xtab1, include.rownames = FALSE, floating = FALSE, 
-            type = "latex", hline.after = hlines, size = "footnotesize", 
-            sanitize.text.function = function(x) {
-                x
-            }, tabular.environment = "longtable")
+    dimnames(out2)[[2]][c(1:2, 2 + s1)] <- col.tit[c(1:2, stats2)]
+    if (length(s2) > 0) {
+        dimnames(out2)[[2]][2 + s2] <- names(stats)[names(stats) != 
+            ""]
+    }
+    for (i in 1:ncols) {
+        align.stats <- paste(align.stats, "r", sep = "")
     }
     if (n.levels == 1) {
-        hlines <- c(-1, 0)
-        out3 <- out2[(1:n.var - 1) * 2 + 1, -2]
-        xtab3 <- xtable(out3, digits = prec[disp.cols2], align = paste(ali, 
-            align.disp.cols, sep = ""), caption = cap, label = lab)
+        prec <- c(rep(0, 2), rep(prec, ncols))
+        ali <- "ll"
+        out2 <- out2[, -2]
+    }
+    if (n.levels > 1) {
+        prec <- c(rep(0, 3), rep(prec, ncols))
+        ali <- "lll"
+    }
+    prec.ind <- dimnames(out2)[[2]] %in% c("n", "\\#NA")
+    prec.ind <- (1:length(prec.ind)) * prec.ind
+    prec.ind <- prec.ind[prec.ind > 0] + 1
+    prec[prec.ind] <- 0
+    tmp <- cumsum(rep(n.levels, n.var) + 1)
+    hlines <- sort(c(0, tmp - 1, rep(tmp, 2)))
+    if (n.levels == 1) {
+        hlines <- 0
+        out3 <- out2[(1:n.var - 1) * 2 + 1, ]
+        xtab3 <- xtable(out3, digits = prec, align = paste(ali, 
+            align.stats, sep = ""), caption = cap, label = lab)
         xtab4 <- print(xtab3, include.rownames = FALSE, floating = FALSE, 
             type = "latex", hline.after = hlines, size = "footnotesize", 
             sanitize.text.function = function(x) {
                 x
             }, tabular.environment = "longtable")
     }
+    if (n.levels > 1) {
+        out2[, 2] <- rep(c(levels(group), "all"), times = n.var)
+        xtab1 <- xtable(out2, digits = prec, align = paste(ali, 
+            align.stats, sep = ""), caption = cap, label = lab)
+        xtab2 <- print(xtab1, include.rownames = FALSE, floating = FALSE, 
+            type = "latex", hline.after = hlines, size = "footnotesize", 
+            sanitize.text.function = function(x) {
+                x
+            }, tabular.environment = "longtable")
+    }
 }
